summaryrefslogtreecommitdiff
path: root/sw/inc/PostItMgr.hxx
diff options
context:
space:
mode:
authorRobinson Tryon <qubit@runcibility.com>2015-11-25 06:03:10 -0500
committerRobinson Tryon <qubit@runcibility.com>2015-11-25 06:07:38 -0500
commit49c2b9808df8a6b197dec666dfc0cda6321a4306 (patch)
tree045ef4b9b8dfdb06bfbe18cdf773d59f57d5552d /sw/inc/PostItMgr.hxx
parent5470a365f25e5052b4dd74f76aa2196f0d70934b (diff)
bin/rename-sw-abbreviations.sh libreoffice-5-1-branch-point
This commit renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I77e5134f42f25e3786afa36b7a505c7e3237a9e8
Diffstat (limited to 'sw/inc/PostItMgr.hxx')
-rw-r--r--sw/inc/PostItMgr.hxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/sw/inc/PostItMgr.hxx b/sw/inc/PostItMgr.hxx
index 3c8324e3dd4d..b41bdb36159f 100644
--- a/sw/inc/PostItMgr.hxx
+++ b/sw/inc/PostItMgr.hxx
@@ -57,10 +57,10 @@ namespace sw { namespace annotation {
}}
namespace sw { namespace sidebarwindows {
class SwSidebarWin;
- class SwFrmSidebarWinContainer;
+ class SwFrameSidebarWinContainer;
}}
class SwSidebarItem;
-class SwFrm;
+class SwFrame;
namespace vcl { class Window; }
struct ImplSVEvent;
@@ -158,8 +158,8 @@ class SwPostItMgr: public SfxListener
OutlinerParaObject* mpAnswer;
bool mbIsShowAnchor;
- // data structure to collect the <SwSidebarWin> instances for certain <SwFrm> instances.
- sw::sidebarwindows::SwFrmSidebarWinContainer* mpFrmSidebarWinContainer;
+ // data structure to collect the <SwSidebarWin> instances for certain <SwFrame> instances.
+ sw::sidebarwindows::SwFrameSidebarWinContainer* mpFrameSidebarWinContainer;
typedef std::list<sw::sidebarwindows::SwSidebarWin*>::iterator SwSidebarWin_iterator;
@@ -277,15 +277,15 @@ class SwPostItMgr: public SfxListener
void AssureStdModeAtShell();
- void ConnectSidebarWinToFrm( const SwFrm& rFrm,
+ void ConnectSidebarWinToFrame( const SwFrame& rFrame,
const SwFormatField& rFormatField,
sw::sidebarwindows::SwSidebarWin& rSidebarWin );
- void DisconnectSidebarWinFromFrm( const SwFrm& rFrm,
+ void DisconnectSidebarWinFromFrame( const SwFrame& rFrame,
sw::sidebarwindows::SwSidebarWin& rSidebarWin );
- bool HasFrmConnectedSidebarWins( const SwFrm& rFrm );
- vcl::Window* GetSidebarWinForFrmByIndex( const SwFrm& rFrm,
+ bool HasFrameConnectedSidebarWins( const SwFrame& rFrame );
+ vcl::Window* GetSidebarWinForFrameByIndex( const SwFrame& rFrame,
const sal_Int32 nIndex );
- void GetAllSidebarWinForFrm( const SwFrm& rFrm,
+ void GetAllSidebarWinForFrame( const SwFrame& rFrame,
std::vector< vcl::Window* >* pChildren );
void DrawNotesForPage(OutputDevice *pOutDev, sal_uInt32 nPage);